the summary as md table

| FROM classification: | Full name                                                                                | Author/organization       | TO classification: | Full name                                                                   | Author/organization                           | Type of clasifications | Correspondence file name                                | Status of the correspondance file  | Author of the correspondance file | Comment                                                                                                                                                            | 
|----------------------|------------------------------------------------------------------------------------------|---------------------------|--------------------|-----------------------------------------------------------------------------|-----------------------------------------------|------------------------|---------------------------------------------------------|------------------------------------|-----------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------| 
| SITC                 | Standard International Trade Classification                                              | United Nations            | CPC                | Central Product Classification                                              | United Nations                                | products               | SITCv4_to_CPCv2.csv                                     | Completed and Verified             | UN                                |                                                                                                                                                                    | 
| SITC                 | Standard International Trade Classification                                              | United Nations            | BEC                | Broad Economic Categories                                                   | United Nations                                | products               | SITCv3_to_BEC.csv                                       | Completed and Verified             | UN                                |                                                                                                                                                                    | 
| SITC                 | Standard International Trade Classification                                              | United Nations            | CN                 | Combined Nomenclature                                                       | European Union                                | products               | SITCv4_to_CN2017.csv                                    | Completed and Verified             | UN                                | CN further details HS at EU level (e.g. it adds sub-categories)                                                                                                    | 
| SITC                 | Standard International Trade Classification                                              | United Nations            | HS                 | Harmonized System                                                           | World Trade Organization                      | products               | SITCv4_to_HS2012.csv                                    | Completed and Verified             | UN                                |                                                                                                                                                                    | 
| CPC                  | Central Product Classification                                                           | United Nations            | SITC               | Standard International Trade Classification                                 | United Nations                                | products               | CPCv2_to_SITCv4.csv                                     | Completed and Verified             | UN                                |                                                                                                                                                                    | 
| CPC                  | Central Product Classification                                                           | United Nations            | FCL                | FAOSTAT Commodity List                                                      | United Nations                                | products               | CPCv2_to_FCL.csv                                        | Completed and Verified             | UN                                |                                                                                                                                                                    | 
| CPC                  | Central Product Classification                                                           | United Nations            | CPA                | Classification of Products by Activity                                      | European Union                                | products               | CPCv2_to_CPA2008.csv                                    | Completed and Verified             | UN                                |                                                                                                                                                                    | 
| UNSPSC               | United Nations Standard Products and Services Code                                       | United Nations            | SITC               | Standard International Trade Classification                                 | United Nations                                | products               |                                                         | Missing                            |                                   |                                                                                                                                                                    | 
| FCL                  | FAOSTAT Commodity List                                                                   | United Nations            | CPC                | Central Product Classification                                              | United Nations                                | products               | FCL_to_CPCv2.csv                                        | Completed and Verified             | UN                                |                                                                                                                                                                    | 
| BEC                  | Broad Economic Categories                                                                | United Nations            | SITC               | Standard International Trade Classification                                 | United Nations                                | products               | BEC_to_SITCv3.csv                                       | Completed and Verified             | UN                                |                                                                                                                                                                    | 
| CPA                  | Classification of Products by Activity                                                   | European Union            | CPC                | Central Product Classification                                              | United Nations                                | products               | CPA2008_to_CPCv2.csv                                    | Completed and Verified             | UN                                | "CPA: Statistical Classification of Products by Activity in the European Economic Community, 2008 version"                                                         | 
| CPA                  | Classification of Products by Activity                                                   | European Union            | HS                 | Harmonized System                                                           | World Trade Organization                      | products               | CPA2008_to_ HS2007.csv                                  | Completed and Verified             | UN                                | "CPA: Statistical Classification of Products by Activity in the European Economic Community, 2008 version; HS: Harmonized Commodity Description and Coding System" | 
| PRODCOM              | PRODuction COMmunautaire                                                                 | European Union            | CN                 | Combined Nomenclature                                                       | European Union                                | products               | PROCOM2017_to_CN2017.csv                                | Completed and Verified             | UN                                | CN further details HS at EU level (e.g. it adds sub-categories)                                                                                                    | 
| CN                   | Combined Nomenclature                                                                    | European Union            | SITC               | Combined Nomenclature                                                       | United Nations                                | products               | CN2017_to_SITCv4.csv                                    | Completed and Verified             | UN                                | CN further details HS at EU level (e.g. it adds sub-categories)                                                                                                    | 
| CN                   | Combined Nomenclature                                                                    | European Union            | PRODCOM            | PRODuction COMmunautaire                                                    | European Union                                | products               | CN_2017_to_PRODCOM_2017.csv                             | Completed and Verified             | UN                                | CN further details HS at EU level (e.g. it adds sub-categories)                                                                                                    | 
| HS                   | Harmonized System                                                                        | World Trade Organization  | SITC               | Standard International Trade Classification                                 | United Nations                                | products               | HS2012_to_SITCv4.csv                                    | Completed and Verified             | UN                                | HS: Harmonized Commodity Description and Coding System                                                                                                             | 
| HS                   | Harmonized System                                                                        | World Trade Organization  | CPA                | Classification of Products by Activity                                      | European Union                                | products               | HS2007_to_CPA2008.csv                                   | Completed and Verified             | UN                                | HS: Harmonized Commodity Description and Coding System                                                                                                             | 
| Exiobase_prod        | Exiobase products classification                                                         | Exiobase                  | Ecoinvent_prod     | Ecoinvent products classification                                           | Ecoinvent                                     | products               |                                                         | Missing                            |                                   |                                                                                                                                                                    | 
| Ecoinvent_prod       | Ecoinvent products classification                                                        | Ecoinvent                 | Exiobase_prod      | Exiobase products classification                                            | Exiobase                                      | products               | Ecoivent3.2_to_exiobase2.csv                            | ?                                  | ?                                 |                                                                                                                                                                    | 
| ELCD_prod            | European Life Cycle Database products classification                                     | ELCD                      | Ecoinvent_prod     | Ecoinvent products classification                                           | Ecoinvent                                     | products               |                                                         | Missing                            |                                   |                                                                                                                                                                    | 
| ISIC                 | International Standard Industrial Classification of All Economic Activities              | United Nations            | NACE Rev 2 (2008)  | Classification of Economic Activities in the European Community             | European Union                                | activities             | ISICv4_to_NACEv2.csv                                    | Completed and Verified             | UN                                | (NACE: nomenclature statistique des activit�s �conomiques dans la Communaut� europ�enne)                                                                           | 
| NACE Rev 2 (2008)    | Classification of Economic Activities in the European Community                          | European Union            | ISIC               | International Standard Industrial�Classification�of All Economic Activities | United Nations                                | activities             | NACEv2_to_ISICv4.csv                                    | Completed and Verified             | UN                                | (NACE: nomenclature statistique des activit�s �conomiques dans la Communaut� europ�enne)                                                                           | 
| Exiobase_act         | Exiobase activities classification                                                       | Exiobase                  | NACE Rev 2 (2008)  | Classification of Economic Activities in the European Community             | European Union                                | activities             | exiobase2_to_NACE2008_v2.csv                            | Incomplete                         | Cyril/Stefano                     |                                                                                                                                                                    | 
| Ecoinvent_act        | Ecoinvent activities classification                                                      | Ecoinvent                 | Exiobase_act       | Exiobase activities classification                                          | Exiobase                                      | activities             | EcoinventAct3.2_to_exiobase2.csv                        | Incomplete                         | Cyril                             |                                                                                                                                                                    | 
| ELCD_act             | European Life Cycle Database activities  classification                                  | ELCD                      | Exiobase_act       | Exiobase activities classification                                          | Exiobase                                      | activities             |                                                         | Missing                            | UN                                |                                                                                                                                                                    | 
| Ecospold 2           | Ecospold 2 elementary flows                                                              | Ecoinvent                 | ILCD               | International Reference Life Cycle Data System's elementary flows           | European Commission - JRC                     | elementary flows       | EcoinventElflow3.2_to_ILCD.csv                          | Completed and Verified             | UN                                |                                                                                                                                                                    | 
| ILCD                 | International Reference Life Cycle Data System's elementary flows                        | European Commission - JRC | Ecospold 2         |                                                                             | Ecoinvent                                     | elementary flows       |                                                         | Missing                            |                                   |                                                                                                                                                                    | 
| Exiobase emissions   | Exiobase emissions                                                                       | Exiobase                  | Ecospold 2         | Ecospold 2 elementary flows                                                 | Ecoinvent                                     | elementary flows       |                                                         | ?                                  | ?                                 |                                                                                                                                                                    | 
| Exiobase_prod        | Exiobase HSUTs products                                                                  | Exiobase                  | Exiobase_HIOT_prod | Exiobase HIOT products                                                      | Exiobase                                      | products               | Exiobase_v3_3_17_HSUTs_HIOT_product_correspondences.csv | Completed                          | Stefano                           |                                                                                                                                                                    | 
| LC_IMPACT            | LC-Impact Version 0.5 - A spatially differentiated life cycle impact assessment approach | LC-Impact                 | US EPA             | United States Environmental Protection Agency                               | United States Environmental Protection Agency | elementary flows       | LC_IMPACT_US_EPA.csv                                    | Completed                          | Tiago                             |                                                                                                                                                                    | 
| Exiobase             | Exiobase activities classification                                                       | Exiobase                  | Bentso             | Bentso model technologies                                                   | Chris Mutel                                   | activities             | Exiobase_to_Bentso.csv                                  | Complete not verified              | Massimo Pizzol                    | N-1 classification                                                                                                                                                 | 
